<?php
namespace Planejamento\Logic\PlanejamentoProducao;

use Geral\Entities\Filial;
use Geral\Util\Ambiente;
use Setforms2\Shared\Registry;

class RotinasGerais
{
    /**
     * Gera o valor da central da filial logada (Se central, retorna a filial logada)
     *
     * @return null
     */

    public static function centralDefault()
    {
        $nrorg    = Ambiente::getNrorg();
        $cdfilial = Ambiente::getCdFilial();

        $filial   = Filial::getObjectByWhere(
            'NRORG = ? AND CDFILIAL = ?',
            array($nrorg, $cdfilial)
        );
        $resultado = $filial->getCdfilcentpme();
        if (empty($resultado)) {
            $filial = Filial::getObjectByWhere('NRORG = ? AND CDFILCENTPME = ?',
            array($nrorg, $cdfilial));
            if ($filial){
                $resultado = $cdfilial;
            }
        }
        return $resultado;
    }

    /**
     * Função responsável por aplicar a consulta especificada no banco de dados e retornar o resultado
     * @param $sql -> consulta especificada
     * @return conjunto de objetos resultantes da consulta
     * @throws \Exception
     */
    public static function aplicaConsulta($sql)
    {
        $connection = Registry::getEntityManager();
        try {
            return $connection->getConnection()->fetchAll($sql, array());
        } catch (\Exception $e) {
            throw new \Exception(tk_get_message_by_name('msg_error_query_aplicada'));
        }
    }

    /**
     * Função responsável por executar no banco de dados um comando INSERT/UPDATE/DELETE
     * @param $sql -> Comando INSERT/UPDATE/DELETE a ser executado
     * @return número de registros afetados
     * @throws \Exception
     */
    public static function executaComando($sql)
    {
        $connection = Registry::getEntityManager();
        try {
            $connection->beginTransaction();
            return $connection->getConnection()->exec($sql);
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollback();
            throw new \Exception(tk_get_message_by_name('msg_error_query_aplicada'));
        }
    }
}